@@ -38,8 +38,8 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor}-(e)k zure e-posta helbidea aldatu du",
     "You changed your email address" : "Zuk zure e-posta helbidea aldatu duzu",
     "Your email address was changed by an administrator" : "Administratzaile batek zure e-posta helbidea berrezarri du",
-    "You created app password \"{token}\"" : "\"{token}\" aplikazio pasahitza sortu duzu",
-    "An administrator created app password \"{token}\"" : "Administratzaile batek \"{token}\" aplikazioaren pasahitza sortu du",
+    "You created an app password for a session named \"{token}\"" : "\"{token}\" izeneko saio baterako aplikazio pasahitza sortu duzu",
+    "An administrator created an app password for a session named \"{token}\"" : "Administratzaile batek aplikazioaren pasahitza sortu du \"{token}\" izeneko saiorako",
     "You deleted app password \"{token}\"" : "\"{token}\" aplikazio pasahitza ezabatu duzu",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "\"{token}\" aplikazio pasahitzaren izena \"{newToken}\" izatera aldatu duzu",
     "You granted filesystem access to app password \"{token}\"" : "\"{token}\" aplikazio pasahitzari fitxategi sistemarako sarbidea eman diozu",
@@ -50,6 +50,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Urruneko garbiketa hasi zen %1$s-ean",
     "Remote wipe has finished on %1$s" : "Urruneko garbiketa amaitu zen %1$s-ean",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Zure pasahitza edo e-posta helbidea aldatu da",
+    "Apps" : "Aplikazioak",
     "Could not remove app." : "Ezin izan da kendu aplikazioa.",
     "Could not update app." : "Ezin izan da aplikazioa eguneratu.",
     "Wrong password" : "Pasahitz okerra",
@@ -70,16 +71,20 @@ OC.L10N.register(
     "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache kodea iruzkinak kentzeko konfiguratuta dago. OPcache gaituta, <code> opcache.save_comments=1 </code> ezarri behar da Nextcloud-ek funtziona dezan.",
     "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud-ek ez du onartzen OPcache APIa erabiltzea. OPcache gaituta dagoela, oso gomendagarria da Nextcloud direktorio guztiak <code> opcache.restrict_api </code>-rekin sartzea edo ezarpen hau desaktibatzea OPcache API-ren murrizketak desgaitzeko, Nextcloud core edo aplikazioen berritze-lanetan akatsak saihesteko.",
     "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud-ek ez du onartzen OPcache APIa erabiltzea. Oso gomendagarria da Nextcloud-en direktorio guztiak <code>opcache.restrict_api </code>-ekin sartzea edo ezarpen hau desaktibatzea OPcache APIaren murrizketak desgaitzeko, Nextcloud core edo aplikazioen eguneratzeetan akatsak saihesteko.",
+    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Partekatutako memorian oinarritutako OPcache desgaituta dago. Errendimendu hobea lortzeko, gomendatzen da <code> opcache.file_cache_only=0 </code> aplikatzea zure PHP konfigurazioan eta fitxategien cachea bigarren mailako cache gisa soilik erabiltzea.",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache gakoen gehienezko kopurua ia gainditzen da. Script guztiak cachean gorde daitezkeela ziurtatzeko,<code>opcache.max_accelerated_files</code>zure PHP konfigurazioan <code> %s </code> baino balio handiagoarekin aplikatzea gomendatzen da.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache buffer-a ia beteta dago. Script guztiak cachean gorde daitezkeela ziurtatzeko, gomendatzen da <code> opcache.memory_consumption </code> aplikatzea zure PHP konfigurazioan <code> %s </code> baino balio handiagoarekin.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache barneratutako kateen buffer-a ia beteta dago. Errepikatzen diren kateak modu eraginkorrean gorde daitezkeela ziurtatzeko, gomendatzen da <code> aplikatzea opcache.interned_strings_buffer </code> zure PHP konfigurazioan <code> %s</code>baino balio handiagoarekin.",
+    "Administrator documentation" : "Administratzaile dokumentazioa",
+    "User documentation" : "Erabiltzailearen dokumentazioa",
     "Invalid SMTP password." : "SMTP pasahitza baliogabea",
     "Email setting test" : "E-postaren ezarpenen proba",
     "Well done, %s!" : "Ongi egina, %s!",
     "If you received this email, the email configuration seems to be correct." : "E-posta mezu hau jaso baduzu, e-postaren ezarpenak egokiak direnaren seinale.",
     "Email could not be sent. Check your mail server log" : "E-posta mezua ezin izan da bidali. Begiratu zure posta-zerbitzariaren egunkaria",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Arazo bat sortu da posta bidaltzerakoan. Berrikusi zure ezarpenak. (Error: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Zure erabiltzailearen posta elektronikoa ezarri behar duzu probako mezu elektronikoak bidali ahal izateko. Joan %s-ra horretarako.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Zure erabiltzailearen posta elektronikoa ezarri behar duzu probako mezu elektronikoak bidali ahal izateko. Zoaz %sorrira horretarako.",
+    "Users" : "Erabiltzaileak",
     "Invalid user" : "Erabiltzaile baliogabea",
     "Invalid mail address" : "Posta helbide baliogabea",
     "Settings saved" : "Ezarpenak gordeta",
@@ -103,15 +108,14 @@ OC.L10N.register(
     "Email address changed for %s" : "%s-(r)en e-posta helbidea aldatu da",
     "The new email address is %s" : "E-posta helbide berria hau da: %s",
     "Your %s account was created" : "Zure %s kontua sortu da",
-    "Welcome aboard" : "Ongi etorri barrura",
-    "Welcome aboard %s" : "Ongi etorri barrura, %s",
+    "Welcome aboard" : "Ongi etorri gurera",
+    "Welcome aboard %s" : "Ongi etorri gurera, %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Ongi etorri zure %s kontura, zure datuak gehitu, babestu eta parteka ditzakezu.",
     "Your username is: %s" : "Zure erabiltzailea hau da: %s",
     "Set your password" : "Ezarri zure pasahitza",
     "Go to %s" : "%s-ra joan",
     "Install Client" : "Instalatu bezeroa",
     "Logged in user must be a subadmin" : "Saioa hasitako erabiltzailea azpi-administratzailea izan behar du",
-    "Apps" : "Aplikazioak",
     "Settings" : "Ezarpenak",
     "Personal" : "Pertsonala",
     "Administration" : "Administrazioa",
@@ -121,6 +125,8 @@ OC.L10N.register(
     "Overview" : "Ikuspegi orokorra",
     "Basic settings" : "Oinarrizko ezarpenak",
     "Sharing" : "Partekatzea",
+    "Availability" : "Eskuragarritasuna",
+    "Calendar" : "Egutegia",
     "Personal info" : "Informazio pertsonala",
     "Mobile & desktop" : "Mugikorra eta mahaigaina",
     "Email server" : "E-posta zerbitzaria",
@@ -168,7 +174,6 @@ OC.L10N.register(
     "View in store" : "Dendan ikusi",
     "Visit website" : "Web orria ikusi",
     "Report a bug" : "Eman akats baten berri ",
-    "User documentation" : "Erabiltzailearen dokumentazioa",
     "Admin documentation" : "Administratzailearen dokumentazioa",
     "Developer documentation" : "Garatzailearen dokumentazioa",
     "This app is supported via your current Nextcloud subscription." : "Aplikazio hau zure Nextcloud harpidetzaren bitartez ahalbidetua dago.",
@@ -205,7 +210,7 @@ OC.L10N.register(
     "Sync client - {os}" : "Sinkronizatu bezeroaren - {os}",
     "This session" : "Saio hau",
     "Device" : "Gailua",
-    "Last activity" : "Azken jarduera",
+    "Last activity" : "Azken jarduerak",
     "Devices & sessions" : "Gailuak eta saioak",
     "Web, desktop and mobile clients currently logged in to your account." : "Webgunean edota mahaigaineko zein mugikorreko bezero hauetan saioa hasita duzu.",
     "Do you really want to wipe your data from this device?" : "Ziur zaude gailu honetatik zure datu guztiak ezabatu nahi dituzula?",
@@ -235,8 +240,7 @@ OC.L10N.register(
     "Webcron" : "Webcron",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php webcron zerbitzu batean erregistratuta dago HTTP bidez 5 minuturo cron.php deitzeko. Erabilera kasua: oso instantzia txikia (1-5 erabiltzaile erabileraren arabera).",
     "Cron (Recommended)" : "Cron (Gomendatuta)",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Hau exekutatzeko PHP POSIX luzapena behar duzu. {linkstart}PHP dokumentazioa{linkend} ikusi informazio gehiagorako",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Erabili sistemaren cron zerbitzua 5 minuturo cron.php fitxategira deitzeko. Instantzia guztietarako gomendatua.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Sistemaren cron zerbitzua erabili cron.php-ri 5 minutuan behin deitzeko.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php sistemaren erabiltzaileak \"{user}\" exekutatu behar du.",
     "Unable to update background job mode" : "Ezin izan da atzeko planoko lan-modua eguneratu",
     "Profile" : "Profila",
@@ -263,19 +267,27 @@ OC.L10N.register(
     "Current password" : "Uneko pasahitza",
     "New password" : "Pasahitz berria",
     "Change password" : "Aldatu pasahitza",
+    "Your profile information" : "Zure profileko informazioa",
     "Your profile picture" : "Zure profil-irudia",
     "Upload profile picture" : "Kargatu profil-irudia",
-    "Choose profile picture from files" : "Aukeratu profil-irudia fitxategietatik",
+    "Choose profile picture from Files" : "Aukeratu Fitxategiak-en profileko argazkia",
     "Remove profile picture" : "Kendu profil-irudia",
-    "png or jpg, max. 20 MB" : "png edo jpg, gehienez 20MB",
+    "The file must be a PNG or JPG" : "Fitxategiak PNG edo JPG izan behar du",
     "Picture provided by original account" : "Irudia jatorrizko kontutik hartuta",
     "Cancel" : "Ezeztatu",
     "Set as profile picture" : "Ezarri profil-irudia",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Kontuan izan profil-irudia edonon eguneratzeko 24 ordu arte igaro daitezkeela.",
     "Choose your profile picture" : "Aukeratu zure profil-irudia",
+    "Please select a valid png or jpg file" : "Mesedez hautatu baliozko png edo jpg fitxategi bat",
+    "Error setting profile picture" : "Errorea profil-irudia ezartzean",
+    "Error cropping profile picture" : "Errorea profil-irudia moztean",
+    "Error saving profile picture" : "Errorea profil-irudia gordetzean",
+    "Error removing profile picture" : "Errorea profil-irudia kentzean",
     "Your biography" : "Zure biografia",
     "Details" : "Xehetasunak",
     "You are a member of the following groups:" : "Honako taldeetako kide zara:",
+    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong> erabiltzen ari zara",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "<strong>{usage}</strong>/<strong>{totalSpace}</strong> erabiltzen ari zara (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Zure izen osoa",
     "Email options" : "Posta elektronikoaren aukerak",
     "Primary email for password reset and notifications" : "Pasahitz berrezartzeko eta jakinarazpenetarako posta elektroniko nagusia",
@@ -293,33 +305,79 @@ OC.L10N.register(
     "Unable to delete additional email address" : "Ezin izan da helbide elektroniko gehigarria ezabatu",
     "No email address set" : "Ez da eposta helbidea ezarri",
     "Additional emails" : "Helbide elektroniko gehigarriak",
+    "Your handle" : "Zure heldulekua",
     "Your headline" : "Zure izenburua",
     "Language" : "Hizkuntza",
     "Help translate" : "Lagundu itzultzen",
     "Unable to update language" : "Ezin izan da hizkuntza eguneratu",
     "No language set" : "Ez da hizkuntzarik ezarri",
     "Locale" : "Eskualdeko ezarpenak",
-    "Your location" : "Zure kokapena",
+    "Week starts on {firstDayOfWeek}" : "Astea {firstDayOfWeek} egunean hasten da",
+    "Unable to update locale" : "Ezin izan da lokalizazioa eguneratu",
+    "No locale set" : "Ez da lokalizaziorik ezarri",
+    "Your city" : "Zure hiria",
     "Your organisation" : "Zure erakundea",
     "Your phone number" : "Zure telefono zenbakia",
     "Edit your Profile visibility" : "Editatu profilaren ikusgarritasuna",
     "Enable Profile" : "Gaitu profila",
     "Unable to update profile enabled state" : "Ezin izan da profila gaitutako egoerara eguneratu",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Ikusgarritasunaren edo esparruaren ezarpen murriztaileena zure profilean errespetatzen da. Esaterako, ikusgarritasuna \"Erakutsi guztiei\" eta esparrua \"Pribatua\" gisa ezarrita badago, \"Pribatua\" errespetatzen da.",
-    "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Ezin izan da {displayId}(r)en ikusgarritasuna eguneratu",
     "Your role" : "Zure rola",
     "Your Twitter handle" : "Zure Twitter erabiltzailea",
     "Your website" : "Zure web orria",
+    "No {property} set" : "Ez da {property} ezarri",
     "Unable to update {property}" : "Ezin izan da {property} eguneratu",
+    "Change scope level of {property}, current scope is {scope}" : "Aldatu {property}-(r)en esparru-maila, unekoa {scope} esparru-maila da",
+    "Unable to update federation scope of the primary {property}" : "Ezin da eguneratu lehen mailako {property}-ren federazio-esparrua",
+    "Unable to update federation scope of additional {property}" : "Ezin da eguneratu {property} gehigarriaren federazio-esparrua",
     "Add additional email" : "Gehitu e-posta gehigarria",
     "Add" : "Gehitu",
-    "You do not have permissions to see the details of this user" : "Ez duzu baimenik erabiltzaile honen xehetasunak ikusteko",
+    "No users" : "Erabiltzailerik ez",
+    "Loading users …" : "Erabiltzaileak kargatzen ...",
+    "Default language" : "Hizkuntza lehenetsia",
+    "Common languages" : "Hizkuntza komunak",
+    "Other languages" : "Beste hizkuntza batzuk",
+    "Password change is disabled because the master key is disabled" : "Pasahitza aldatzea desgaituta dago gako nagusia desaktibatuta baitago.",
+    "New user" : "Erabiltzaile berria",
+    "Display name" : "Erakusteko izena",
+    "Either password or email is required" : "Posta elektronikoa edo pasahitza beharrezkoak dira",
+    "Password (required)" : "Pasahitza (beharrezkoa)",
+    "Email (required)" : "Posta elektronikoa (beharrezkoa)",
+    "Email" : "E-posta",
+    "Groups (required)" : "Taldeak (beharrezkoa)",
+    "Set user groups" : "Ezarri erabiltzailearen taldeak",
+    "Administered groups" : "Administratturiko taldeak",
+    "Set user as admin for …" : "Ezarri erabiltzailea admin gisa honentzat...",
+    "Quota" : "Kuota",
+    "Set user quota" : "Ezarri erabiltzaie-kuota",
+    "Set default language" : "Ezarri hizkuntza lehenetsia",
+    "Manager" : "Zuzendaria",
+    "Add new user" : "Gehitu erabiltzaile berria",
+    "Set user manager" : "Ezarri erabiltzaile-kudeatzailea",
+    "Username will be autogenerated" : "Erabiltzaile izena automatikoki sortuko da",
+    "Username (required)" : "Erabiltzailea (beharrezkoa)",
+    "Total rows summary" : "Errenkaden guztirako laburpena",
+    "Scroll to load more rows" : "Mugitu pantailan behera errenkada gehiago kargatzeko",
+    "_{userCount} user …_::_{userCount} users …_" : ["Erabiltzaile {userCount} …","{userCount} erabiltzaile …"],
+    "_{userCount} user_::_{userCount} users_" : ["Erabiltzaile {userCount}","{userCount} erabiltzaile"],
+    "Avatar" : "Avatarra",
+    "Group admin for" : "Talde honen administratzailea",
+    "User backend" : "Erabiltzaile jatorria",
+    "Storage location" : "Biltegiratze kokapena",
+    "Last login" : "Azken saioa",
+    "User actions" : "Erabiltzaile-ekintzak",
+    "Password or insufficient permissions message" : "Pasahitz edo baimen gutxiegiko mezua",
+    "Loading user …" : "Erabiltzailea kargatzen ...",
+    "Edit display name" : "Editatu erakutsiko den izena",
     "Add new password" : "Gehitu pasahitz berria",
+    "You do not have permissions to see the details of this user" : "Ez duzu baimenik erabiltzaile honen xehetasunak ikusteko",
     "Add new email address" : "Gehitu e-mail helbide berria",
     "Add user to group" : "Gehitu erabiltzailea taldera",
     "Set user as admin for" : "Ezarri erabiltzailea admin gisa",
     "Select user quota" : "Aukeratu erabiltzaile-kuota ",
+    "Set the language" : "Ezarri hizkuntza",
+    "{size} used" : "{size} erabilita",
     "Delete user" : "Ezabatu erabiltzailea",
     "Wipe all devices" : "Garbitu gailu guztiak",
     "Disable user" : "Desgaitu erabiltzailea",
@@ -328,29 +386,24 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Gailua galtzen baduzu edo erakundetik irteten bazara, honek {userid} erabiltzaileari lotutako gailu guztietako Nextcloudeko datuak garbitu ditzake. Gailuak internetera konektatuta badaude bakarrik funtzionatzen du.",
     "Remote wipe of devices" : "Gailuen urruneko garbiketa",
     "Wipe {userid}'s devices" : "Garbitu {userid}-ren gailuak",
-    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} erabiltzaileran kontua bere fitxategi eta aplikazioen datuak barne guztiz ezabatu.",
+    "Wiped {userid}'s devices" : "{userid}-ren gailuak garbitu dira",
+    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} erabiltzailearen kontua, bere fitxategi eta aplikazioen datuak barne, guztiz ezabatu.",
     "Account deletion" : "Kontu ezabaketa",
     "Delete {userid}'s account" : "Ezabatu {userid} erabiltzailearen kontua",
+    "Display name was successfully changed" : "Erakusteko izena ondo aldatu da",
+    "Password was successfully changed" : "Pasahitza ondo aldatu da",
+    "Email was successfully changed" : "Posta elektronikoa ondo aldatu da",
     "Welcome mail sent!" : "Ongi etorri mezua bidalita!",
-    "Edit User" : "Erabiltzailea editatu",
     "Toggle user actions menu" : "Txandakatu erabiltzailearen ekintza menua",
-    "{size} used" : "{size} erabilita",
-    "New user" : "Erabiltzaile berria",
-    "Will be autogenerated" : "Automatikoki sortuko da",
-    "Display name" : "Erakusteko izena",
-    "Email" : "E-posta",
-    "Default language" : "Hizkuntza lehenetsia",
-    "Add a new user" : "Gehitu erabiltze berria",
-    "Group admin for" : "Talde honen administratzailea",
-    "Quota" : "Kuota",
-    "User backend" : "Erabiltzaile jatorria",
-    "Storage location" : "Biltegiratze kokapena",
-    "Last login" : "Azken saioa",
-    "No users in here" : "Ez dago erabiltzailerik hemen",
+    "Edit" : "Aldatu",
+    "Visibility" : "Ikusgarritasuna",
+    "Show user backend" : "Bistaratu erabiltzaile motorra",
+    "Show storage path" : "Erakutsi biltegiaren bidea",
+    "Show last login" : "Azken izen ematea erakutsi",
+    "Send email" : "Bidali posta-mezua",
+    "Defaults" : "Defektuzkoak",
     "Default quota" : "Kuota lehenetsia",
-    "Common languages" : "Hizkuntza komunak",
-    "Other languages" : "Beste hizkuntza batzuk",
-    "Password change is disabled because the master key is disabled" : "Pasahitza aldatzea desgaituta dago gako nagusia desaktibatuta baitago.",
+    "Select default quota" : "Aukeratu lehenetsitako kuota",
     "Passwordless authentication requires a secure connection." : "Pasahitzik gabeko autentifikazioak konexio segurua behar du.",
     "Add WebAuthn device" : "Gehitu WebAuthn gailua",
     "Please authorize your WebAuthn device." : "Mesedez, baimendu zure WebAuthn gailua.",
@@ -365,11 +418,6 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Hurrengo gailuak zure konturako konfiguratuta daude:",
     "Your browser does not support WebAuthn." : "Zure nabigatzaileak ez du WebAuthn onartzen.",
     "Your apps" : "Zure aplikazioak",
-    "Active apps" : "Aplikazio aktiboak",
-    "Disabled apps" : "Gaitu gabeko aplikazioak",
-    "Updates" : "Eguneraketak",
-    "App bundles" : "Aplikazio sortak",
-    "Featured apps" : "App aipagarriak",
     "{license}-licensed" : "{license}-lizentziaduna",
     "Changelog" : "Aldaketak",
     "by {author}\n{license}" : "{autor}-(e)k egina\n{license}",
@@ -378,13 +426,6 @@ OC.L10N.register(
     "Active users" : "Erabiltzaile aktiboak",
     "Admins" : "Administratzaileak",
     "Disabled users" : "Erabiltzaile ezinduak",
-    "Default quota:" : "Lehenetsitako kuota:",
-    "Select default quota" : "Aukeratu lehenetsitako kuota",
-    "Show Languages" : "Erakutsi Hizkuntzak",
-    "Show last login" : "Azken izen ematea erakutsi",
-    "Show user backend" : "Bistaratu erabiltzaile motorra",
-    "Show storage path" : "Erakutsi biltegiaren bidea",
-    "Send email to new user" : "Bidali eposta erabiltzaile berriari",
     "Not saved" : "Ez da gorde",
     "Sending…" : "Bidaltzen...",
     "Email sent" : "Eposta bidalia",
@@ -398,10 +439,17 @@ OC.L10N.register(
     "Phone number" : "Telefono zenbakia",
     "Role" : "Zeregina",
     "Twitter" : "Twitter",
+    "Fediverse (e.g. Mastodon)" : "Fedibertsoa (adibidez, Mastodon)",
     "Website" : "Webgunea",
     "Profile visibility" : "Profilaren ikusgarritasuna",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ez dago eskuragarri propietate hau oinarrizko funtzionaltasunentzako beharrezkoa delako, fitxategien partekatze eta egutegien gonbidapenak barne",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Ez dago erabilgarri federazioa desgaitu delako zure kontuan, jarri harremanetan sistema-administratzailearekin galderarik baduzu",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Ez dago eskuragarri bilaketa zerbitzarira erabiltzaileen datu zehatzak argitaratzea ez dagoelako baimenduta, jarri harremanetan sistemaren administratzailearekin galderarik baduzu",
+    "Active apps" : "Aplikazio aktiboak",
+    "Disabled apps" : "Gaitu gabeko aplikazioak",
+    "Updates" : "Eguneraketak",
+    "App bundles" : "Aplikazio sortak",
+    "Featured apps" : "App aipagarriak",
     "Show to everyone" : "Erakutsi denei",
     "Show to logged in users only" : "Erakutsi saioa hasi duten erabiltzaileei soilik",
     "Hide" : "Ezkutatu",
@@ -413,30 +461,27 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Errorea gertatu da eskaeran. Ezin da jarraitu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikazioa gaitu da baina eguneratu behar da. Eguneratze orrira joango zara 5 segundotan.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Errorea: aplikazio hau ezin da gaitu zerbitzaria ezegonkorra izatea eragiten duelako",
-    "Administrator documentation" : "Administratzaile dokumentazioa",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin hau errorea bada.",
     "Documentation" : "Dokumentazioa",
     "Forum" : "Foroa",
     "Login" : "Saio hasiera",
-    "Plain" : "Arrunta",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "None/STARTTLS" : "Batere ez/STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "Ireki dokumentazioa",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Zerbitzaria epostak bidaltzeko gai izatea garrantzitsua da, pasahitzak berrezartzeko eta abisuentzako",
     "Send mode" : "Bidaltzeko modua",
     "Encryption" : "ZIfratzea",
     "Sendmail mode" : "Sendmail modua",
     "From address" : "Helbidetik",
-    "Authentication method" : "Autentifikazio metodoa",
-    "Authentication required" : "Autentikazioa beharrezkoa",
     "Server address" : "Zerbitzariaren helbidea",
     "Port" : "Portua",
+    "Authentication" : "Autentifikazioa",
+    "Authentication required" : "Autentikazioa beharrezkoa",
     "Credentials" : "Kredentzialak",
     "SMTP Username" : "SMTP erabiltzaile-izena",
     "SMTP Password" : "SMTP pasahitza",
     "Save" : "Gorde",
     "Test and verify email settings" : "Probatu eta egiaztatu posta elektronikoaren ezarpenak",
-    "Send email" : "Bidali posta-mezua",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zure instantziaren segurtasuna eta funtzionamenduarentzat oso garrantzitsua da dena ondo konfiguratuta egotea. Horretan laguntzeko egiaztapen automatiko batzuk egiten ditu tresnak bera. Irakurri estekatutako dokumentazioa informazio gehiago lortzeko.",
     "All checks passed." : "Egiaztapen guztiak gaindituta.",
     "There are some errors regarding your setup." : "Zure ezarpenen artean errore batzuk daude.",
@@ -465,8 +510,8 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Mugatu partekatzeak taldeko erabiltzaileetara",
     "Exclude groups from sharing" : "Baztertu taldeak partekatzean",
     "These groups will still be able to receive shares, but not to initiate them." : "Talde hauek oraindik jaso ahal izango dute partekatzeak, baina ezingo dute partekatu",
-    "Allow username autocompletion in share dialog" : "Baimendu erabiltzaile-izenaren osatze automatikoa partekatze elkarrizketan",
-    "Allow username autocompletion to users within the same groups" : "Baimendu erabiltzaile-izenen osatze automatikoa talde bereko erabiltzaileei",
+    "Allow username autocompletion in share dialog and allow access to the system address book" : "Baimendu erabiltzaile izena automatikoki osatzea elkarrizketa-koadroan eta baimendu sistemako helbide-liburua atzitzea",
+    "Allow username autocompletion to users within the same groups and limit system address books to users in the same groups" : "Baimendu erabiltzaile izena automatikoki osatzea talde bereko erabiltzaileei eta mugatu sistemako helbide-liburuak atzitzea talde bereko erabiltzaileei",
     "Allow username autocompletion to users based on phone number integration" : "Baimendu erabiltzaile-izenen osatze automatikoa telefono zenbakien integrazioan oinarritutako erabiltzaileei",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Osatze automatikoa \"talde bera\" eta \"telefono zenbakiaren integrazioa\" gaituta badaude, bat-etortzea nahikoa da erabiltzaileari erakusteko.",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Baimendu automatikoki osatzea izen osoa edo helbide elektronikoa sartzerakoan (alde batera utziz falta den telefono-liburuarekin bat etortzea eta talde berean egotea)",
@@ -483,71 +528,29 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta berehalako jakinarazpenak ez daude eskuragarri.",
     "Use a second factor besides your password to increase security for your account." : "Zure pasahitzaz gain bigarren faktore bat erabiltzeak zure kontua seguruago egingo du.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hirugarrenen aplikazioak erabiltzen badituzu Nextcloud-era konektatzeko, ziurtatu bakoitzarentzako aplikazioaren pasahitza sortu eta konfiguratzen duzula bigarren faktorearen autentifikazioa gaitu aurretik.",
-    "Migration in progress. Please wait until the migration is finished" : "Migratzen ari da. Itxaron migrazioa osatu arte.",
-    "Migration started …" : "Migrazioa hasi da...",
-    "An error occurred while changing your language. Please reload the page and try again." : "Errore bat gertatu da zure hizkuntza aldatzean. Birkargatu orria eta saiatu berriro.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Errore bat gertatu da zure locale-a aldatzean. Birkargatu orria eta saiatu berriro.",
-    "Select a profile picture" : "Hautatu profil-irudi bat",
-    "Week starts on {fdow}" : "Astea {fdow}n hasten da",
-    "Couldn't remove app." : "Ezin izan da aplikazioa kendu.",
-    "Couldn't update app." : "Ezin izan da aplikazioa eguneratu.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Motorrak ez du onartzen pasahitza aldatzea, baina erabiltzailearen zifratze-gakoa eguneratu da.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Ezin izan da zehaztu cURLren TLS bertsioa zaharkituta dagoen edo ez, https://nextcloud.com-ekiko HTTPS eskaeran errore bat gertatu delako. Xehetasun gehiagorako, begiratu nextcloud erregistro fitxategia.",
-    "You need to set your user email before being able to send test emails." : "Epostaren erabiltzailea zehaztu behar duzu probako eposta bidali aurretik.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Token hau baliogabetzen baduzu zure gailua garbitzea ezinezkoa gerta daiteke garbiketa jada ez bada hasi.",
-    "Set as primary mail" : "Ezarri posta nagusi bezala",
-    "Change privacy level of email" : "Aldatu posta elektronikoaren pribatutasun maila",
-    "All languages" : "Hizkuntza guztiak",
-    "Everyone" : "Guztiak",
-    "An error occured during the request. Unable to proceed." : "Errorea gertatu da eskaera egitean. Ezin da jarraitu.",
-    "Test email settings" : "Probatu eposta ezarpenak",
-    "Please read carefully before activating server-side encryption: " : "Mesedez, irakurri arretaz zerbitzariaren aldeko zifratzea gaitu aurretik:",
-    "Enable encryption" : "Gaitu zifratzea",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Zifratze-gakoak zifratze-sistema zaharretik (ownCloud <=8.0) sistema berrira migratu behar duzu. Gaitu mesedez \"Zifratze modulu lehenetsia\" eta 'occ encryption:migrate' exekuta ezazu",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Zifratze-gakoak sistema zaharretik (ownCloud <=8.0) berrira migratu behar duzu",
-    "Start migration" : "Migrazioa hasi",
-    "Last job execution ran %s. Something seems wrong." : "Azken lanaren exekuzioak %s itzuli zuen. Zerbait gaizki joan da ",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Ataza batzuk ez dira %stik exekutatu. Aztertu exekuzio maiztasuna handitzea.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Ataza batzuk ez dira %stik exekutatu. Aztertu sistemaren crona erabiltzera pasatzea.",
-    "Last job ran %s." : "Azken lana %s itzuli zuen. ",
-    "Background job didn’t run yet!" : "Atzeko planoko lana ez da martxan jarri oraindik!",
-    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Zerbitzariak behar bezala funtziona dezan, garrantzitsua da atzeko planoko lanak behar bezala konfiguratzea. \"Cron\" gomendatutako ezarpena da. Ikusi dokumentazioa informazio gehiago lortzeko.",
-    "Pick background job setting" : "Aukeratu atzeko planoko atazen ezarpena",
-    "Recommended" : "Aholkatuta",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Sistemako \"%s\" erabiltzaileak, cron.php exekutatu behar du.",
-    "days" : "egun",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Baimendu erabiltzaile-izena automatikoki osatzea izen osoa edo helbide elektronikoa idazterakoan (falta den telefono-agendaren bat-etortzea eta talde berean egotea alde batera utziz)",
-    "Change privacy level of profile picture" : "Aldatu profileko irudiaren pribatutasun maila",
-    "Upload new" : "Kargatu berria",
-    "Select from Files" : "Aukeratu fitxategien artean",
-    "Remove image" : "Kendu irudia",
-    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Kontuan izan avatarra edonon eguneratzeko 24 ordu arte igaro daitezkeela.",
-    "Choose as profile picture" : "Aukeratu profil irudi gisa",
-    "You are using <strong>%s</strong>" : "<strong>%s</strong> erabiltzen ari zara",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "<strong>%2$s</strong>tik <strong>%1$s</strong> erabiltzen ari zara (<strong>%3$s%%</strong>)",
-    "Change privacy level of full name" : "Aldatu izen osoaren pribatutasun maila",
-    "No display name set" : "Ez da bistaratze izena ezarri",
-    "Change privacy level of phone number" : "Aldatu telefono zenbakiaren pribatutasun maila",
-    "Address" : "Helbidea",
-    "Change privacy level of address" : "Aldatu pribatutasun helbide maila",
-    "Your postal address" : "Zure helbidea",
-    "Change privacy level of website" : "Aldatu webgunearen pribatutasun maila",
-    "It can take up to 24 hours before the account is displayed as verified." : "24 ordu pasa daitezke kontua ziurtatua bezala agertu baino lehen",
-    "Link https://…" : "https://... esteka",
-    "Change privacy level of Twitter profile" : "Aldatu Twitter profilaren pribatutasun maila",
-    "Twitter handle @…" : "Twitter heldulekua @...",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache gakoen gehienezko kopurua ia gainditzen da. Script guztiak cachean gorde daitezkeela ziurtatzeko, gomendatzen da <code>opcache.max_accelerated_files </code> aplikatzea zure PHP konfigurazioan <code> %s</code> baino balio handiagoarekin.",
-    "Admin privileges" : "Administratzaile pribilegioak",
-    "Unable to update biography" : "Ezin izan da biografia eguneratu",
-    "Unable to update full name" : "Ezin izan da izen osoa eguneratu",
-    "No full name set" : "Ez da izen osoa ezarri",
-    "Unable to update headline" : "Ezin izan da izenburua eguneratu",
-    "Unable to update organisation" : "Ezin izan da erakundea eguneratu",
-    "Unable to update role" : "Ezin izan da rola eguneratu",
-    "Change scope level of {accountProperty}" : "Aldatu {accountProperty}-(r)en esparru-maila",
-    "Unable to update federation scope of the primary {accountProperty}" : "Ezin da eguneratu lehen mailako {accountProperty}-ren federazio-esparrua",
-    "Unable to update federation scope of additional {accountProperty}" : "Ezin da eguneratu {accountProperty} gehigarriaren federazio-esparrua",
-    "Avatar" : "Avatarra",
-    "User already exists." : "Erabiltzailea dagoeneko existitzen da."
+    "You created app password \"{token}\"" : "\"{token}\" aplikazio pasahitza sortu duzu",
+    "An administrator created app password \"{token}\"" : "Administratzaile batek \"{token}\" aplikazioaren pasahitza sortu du",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Hau exekutatzeko PHP POSIX luzapena behar duzu. {linkstart}PHP dokumentazioa{linkend} ikusi informazio gehiagorako",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Erabili sistemaren cron zerbitzua 5 minuturo cron.php fitxategira deitzeko. Instantzia guztietarako gomendatua.",
+    "Choose profile picture from files" : "Aukeratu profil-irudia fitxategietatik",
+    "png or jpg, max. 20 MB" : "png edo jpg, gehienez 20MB",
+    "Your location" : "Zure kokapena",
+    "Edit User" : "Erabiltzailea editatu",
+    "Will be autogenerated" : "Automatikoki sortuko da",
+    "Add a new user" : "Gehitu erabiltze berria",
+    "No users in here" : "Ez dago erabiltzailerik hemen",
+    "Default quota:" : "Lehenetsitako kuota:",
+    "Show Languages" : "Erakutsi Hizkuntzak",
+    "Send email to new user" : "Bidali eposta erabiltzaile berriari",
+    "Plain" : "Arrunta",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Authentication method" : "Autentifikazio metodoa",
+    "Allow username autocompletion in share dialog" : "Baimendu erabiltzaile-izenaren osatze automatikoa partekatze elkarrizketan",
+    "Allow username autocompletion to users within the same groups" : "Baimendu erabiltzaile-izenen osatze automatikoa talde bereko erabiltzaileei",
+    "Select manager" : "Aukeratu kudeatzailea",
+    "User's table" : "Erabiltzailearen mahaia",
+    "Select user manager" : "Aukeratu erabiltzaile kudeatzailea"
 },
 "nplurals=2; plural=(n != 1);");
