@@ -2,15 +2,15 @@ OC.L10N.register(
     "settings",
     {
     "Private" : "خصوصی",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "فقط برای کاربرانی فعال است که از طریق یکپارچه سازی شماره تلفن در برنامه Talk روی تلفن همراه مطابقت داشته باشند",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
     "Local" : "محلی",
-    "Only visible to people on this instance and guests" : "فقط برای کاربران این نسخه و مهمانان قابل مشاهده است",
-    "Federated" : "فدرال",
-    "Only synchronize to trusted servers" : "فقط با سرورهای قابل اعتماد همگام سازی شود",
+    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
+    "Federated" : "همگانی",
+    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
     "Published" : "منتشر شده",
-    "Synchronize to trusted servers and the global and public address book" : "با سرورهای قابل اعتماد و دفترچه آدرس عمومی و همگانی همگام سازی شود",
-    "Verify" : "تأیید کنید",
-    "Verifying …" : "در حال تایید ...",
+    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
+    "Verify" : "تأیید",
+    "Verifying …" : "تأیید کردن…",
     "Unable to change password" : "نمی‌توان رمز را تغییر داد",
     "Very weak password" : "رمز عبور بسیار ضعیف",
     "Weak password" : "رمز عبور ضعیف",
@@ -18,38 +18,37 @@ OC.L10N.register(
     "Good password" : "رمز عبور خوب",
     "Strong password" : "رمز عبور قوی",
     "Groups" : "گروه ها",
-    "Group list is empty" : "لیست گروه ها خالی است.",
-    "Unable to retrieve the group list" : "بازیابی لیست گروه امکان پذیر نیست",
-    "{actor} added you to group {group}" : "{actor} شما را به گروه {group} اضافه کرد",
-    "You added {user} to group {group}" : "شما {user} را به گروه {group} اضافه کردید.",
-    "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} اضافه کرد",
-    "An administrator added you to group {group}" : "یک مدیر شما را به گروه {group} اضافه کرد.",
-    "An administrator added {user} to group {group}" : "یک مدیر {user}  را به گروه {group} اضافه کرد.",
-    "{actor} removed you from group {group}" : "{actor} شما را از گروه {group} حذف کرد",
-    "You removed {user} from group {group}" : "شما {user} را از گروه {group} حذف کردید.",
-    "{actor} removed {user} from group {group}" : "{actor} کاربر {user} را از گروه {group} حذف کرد",
-    "An administrator removed you from group {group}" : "یک مدیر شما را از گروه {group}  حذف کرد.",
-    "An administrator removed {user} from group {group}" : "یک مدیر {user} را از گروه {group} حذف کرد.",
-    "Your <strong>group memberships</strong> were modified" : "عضویت در<strong> گروه شما </strong>تغییر یافت",
-    "{actor} changed your password" : "{actor} رمز عبور خود را تغییر داد",
-    "You changed your password" : "رمزعبور خود را تغییر دادید",
-    "Your password was reset by an administrator" : "رمز عبور شما توسط یه مدیر تنظیم مجدد شد.",
-    "Your password was reset" : "رمز عبور شما رمز عبور شما بازنشانی شد",
-    "{actor} changed your email address" : "{actor} پست الکترونیک خود را تغییر داد",
-    "You changed your email address" : "پست الکترونیک خود را تغییر دادید",
-    "Your email address was changed by an administrator" : "پست الکترونیک شما توسط یه مدیر تنظیم مجدد شد.",
-    "You created app password \"{token}\"" : "رمز عبور برنامه توسط شما ایجاد شده است \"{token}\"",
-    "An administrator created app password \"{token}\"" : "یک مدیر \"{token}\"  گذرواژه برنامه را ایجاد کرد",
-    "You deleted app password \"{token}\"" : "رمز عبور برنامه توسط شما حذف شده است \"{token}\"",
-    "You renamed app password \"{token}\" to \"{newToken}\"" : "شما رمزعبور برنامه را از \"{token}\" به {newToken} تغییر دادید ",
-    "You granted filesystem access to app password \"{token}\"" : "دسترسی شما به فایل سیستم به رمز ورود برنامه اعطا گردید \"{token}\"",
-    "You revoked filesystem access from app password \"{token}\"" : "دسترسی شما به فایل سیستم از طریق رمز ورود برنامه باطل گردید \"{token}\"",
+    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
+    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
+    "{actor} added you to group {group}" : "{actor} به گروه {group} افزودتان",
+    "You added {user} to group {group}" : "{user} را به گروه {group} افزودید",
+    "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} افزود",
+    "An administrator added you to group {group}" : "مدیری به گروه {group} افزودتان",
+    "An administrator added {user} to group {group}" : "مدیری {user}  را به گروه {group} افزود",
+    "{actor} removed you from group {group}" : "{actor} از گروه {group} برداشتتان",
+    "You removed {user} from group {group}" : "{user} را از گروه {group} برداشتید",
+    "{actor} removed {user} from group {group}" : "{actor} کاربر {user} را از گروه {group} برداشت",
+    "An administrator removed you from group {group}" : "مدیری از گروه {group} برداشتتان",
+    "An administrator removed {user} from group {group}" : "مدیری {user} را از گروه {group} برداشت",
+    "Your <strong>group memberships</strong> were modified" : "<strong>عضویتتان در گروه</strong> تغییر یافت",
+    "{actor} changed your password" : "{actor} گذرواژه‌تان را تغییر داد",
+    "You changed your password" : "گذرواژه‌تان را تغییر دادید",
+    "Your password was reset by an administrator" : "گذرواژه‌تان به دست مدیری بازنشانی شد",
+    "Your password was reset" : "گذرواژه‌تان بازنشانی شد",
+    "{actor} changed your email address" : "{actor} نشانی رایانامه‌تان را تغییر داد",
+    "You changed your email address" : "نشانی رایانامه‌تان را تغییر دادید",
+    "Your email address was changed by an administrator" : "نشانی رایانامه‌تان به دست مدیری عوض شد",
+    "You deleted app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را حذف کردید",
+    "You renamed app password \"{token}\" to \"{newToken}\"" : "نام گذرواژهٔ کارهٔ «{token}» را به «{newToken}» تغییر دادید",
+    "You granted filesystem access to app password \"{token}\"" : "دسترسی به سامانه‌پرونده را به گذرواژهٔ کارهٔ «{token}» اعطا کردید",
+    "You revoked filesystem access from app password \"{token}\"" : "دسترسی به سامانه‌پرونده را از گذرواژهٔ کارهٔ «{token}» گرفتید",
     "Security" : "امنیت",
     "You successfully logged in using two-factor authentication (%1$s)" : "شما با موفقیت با استفاده از تأیید هویت دو عاملی وارد سیستم شدید(%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "تلاش برای ورود به سیستم با استفاده از تأیید هویت دو عاملی انجام نشد (%1$s)",
     "Remote wipe was started on %1$s" : "پاک کردن از راه دور شروع شد %1$s",
     "Remote wipe has finished on %1$s" : "پاک کردن از راه دور به پایان رسید%1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>پسورد</strong> و یا  <strong>پست الکترونیک</strong> شما ویراش شد.",
+    "Apps" : "برنامه ها",
     "Could not remove app." : "امکان حذف برنامه وجود ندارد.",
     "Could not update app." : "برنامه را نمی توان به روزرسانی کرد .",
     "Wrong password" : "رمز عبور اشتباه است",
@@ -63,12 +62,15 @@ OC.L10N.register(
     "Federated Cloud Sharing" : "اشتراک گذاری ابر فدرال",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL از نسخه (%2$s) منسوخ شده %1$s استفاده می کند. لطفا سیستم عامل خود را به روز کنید یا ویژگی هایی از قبیل %3$s قابل اعتماد کار نمی کنند.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "نمی توان تعیین کرد که آیا نسخه TLS متعلق به cURL قدیمی است یا خیر. زیرا خطایی در طول درخواست HTTPS به https://nextcloud.com رخ داده است. لطفاً فایل گزارش نکست‌کلود را برای جزئیات بیشتر بررسی کنید.",
+    "Administrator documentation" : "مستندات مدیر",
+    "User documentation" : "مستندات کاربر",
     "Invalid SMTP password." : "گذرواژه SMTP نامعتبر است.",
     "Email setting test" : "تست تنظیم پست الکترونیک",
     "Well done, %s!" : "انجام شد،%s!",
     "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
     "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
+    "Users" : "کاربران",
     "Invalid user" : "کاربر نامعتبر",
     "Invalid mail address" : "آدرس ایمیل نامعتبر است",
     "Settings saved" : "تنظیمات ذخیره شد",
@@ -96,82 +98,90 @@ OC.L10N.register(
     "Go to %s" : "برو به %s",
     "Install Client" : "قسمت مشتری را نصب کنید",
     "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
-    "Apps" : "برنامه ها",
     "Settings" : "تنظیمات",
     "Personal" : "شخصی",
     "Administration" : "مدیریت",
     "Additional settings" : "تنظیمات اضافی",
-    "Groupware" : "گروه های نرم افزاری",
-    "Overview" : "بررسی اجمالی",
+    "Administration privileges" : "اجازه‌های مدیریتی",
+    "Groupware" : "کار گروهی",
+    "Overview" : "نمای کلّی",
     "Basic settings" : "تنظیمات پایه",
     "Sharing" : "اشتراک گذاری",
-    "Personal info" : "مشخصات شخصی",
-    "Mobile & desktop" : "موبایل و دسک تاپ",
+    "Availability" : "موجود بودن",
+    "Calendar" : "تقویم",
+    "Personal info" : "اطّلاعات شخصی",
+    "Mobile & desktop" : "همراه و میزکار",
     "Email server" : "سرور ایمیل",
     "Security & setup warnings" : "اخطارهای نصب و امنیتی",
-    "Background jobs" : "کارهای پس زمینه",
-    "Create" : "ساختن",
-    "Change" : "تغییرات",
+    "Background jobs" : "کارهای پس‌زمینه",
+    "Create" : "ایجاد",
+    "Change" : "تغییر",
     "Delete" : "حذف",
-    "Reshare" : "دوباره به اشتراک گذاشتن",
+    "Reshare" : "بازهم‌رسانی",
     "Unlimited" : "نامحدود",
-    "Verifying" : "تایید شدن",
+    "Verifying" : "تآیید کردن",
     "Nextcloud settings" : "تنظیمات نکست کلود",
     "None" : "هیچ‌کدام",
     "Two-Factor Authentication" : "احراز هویت دو عاملی",
     "Enforce two-factor authentication" : "احراز هویت دو عاملی",
-    "Limit to groups" : "محدود کردن به گروه ها",
-    "Enforcement of two-factor authentication can be set for certain groups only." : "اجرای احراز هویت دو عاملی فقط برای گروههای خاص قابل تنظیم است.",
-    "Enforced groups" : "گروههای اجباری",
-    "Excluded groups" : "گروه های مستثنی",
+    "Limit to groups" : "محدود کردن به گروه‌ها",
+    "Enforcement of two-factor authentication can be set for certain groups only." : "اجبار به احراز هویت دو عاملی فقط می‌تواند برای گروه‌هایی خاص تنظیم شود.",
+    "Enforced groups" : "گروه‌های اجباری",
+    "Excluded groups" : "گروه‌های مستثنی",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
-    "Save changes" : "ذخیره تغییرات",
+    "Save changes" : "ذخیرهٔ تغییرات",
     "All" : "همه",
-    "Limit app usage to groups" : "استفاده از برنامه را به گروهها محدود کنید",
-    "No results" : "نتیجه ای یافت نشد",
-    "Update to {version}" : "بروزرسانی به  {version}",
+    "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
+    "No results" : "بدون نتیجه",
+    "Update to {version}" : "به‌روز رسانی به {version}",
     "Remove" : "برداشتن",
     "Disable" : "غیرفعال",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
     "View in store" : "نمایش در فروشگاه",
-    "Visit website" : "مشاهده وب‌سایت",
+    "Visit website" : "سر زدن به پایگاه وب",
     "Report a bug" : "گزارش یک خطا",
-    "User documentation" : "مستندات کاربر",
     "Admin documentation" : "مستندات مدیر",
     "Developer documentation" : "مستندات توسعه‌دهندگان",
-    "This app is supported via your current Nextcloud subscription." : "این برنامه از طریق اشتراک فعلی نکست کلوذ شما پشتیبانی می شود.",
-    "Supported" : "پشتیبانی",
-    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه های ویژه توسط و در داخل جامعه توسعه داده می شوند. آنها عملکردهای مرکزی را ارائه می دهند و برای استفاده در تولید آماده هستند.",
-    "Featured" : "ویژه",
-    "Update to {update}" : "بروزرسانی به {update} ",
-    "Results from other categories" : "نتایج از دسته های دیگر",
+    "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
+    "Supported" : "پشتیبانی شده",
+    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
+    "Featured" : "برگزیده",
+    "Update to {update}" : "به‌روز رسانی به {update} ",
+    "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
+    "Results from other categories" : "نتایج از دیگر دسته‌ها",
     "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
-    "Disable all" : "غیرفعال کردن همه",
-    "Enable all" : "فعال کردن همه",
-    "Marked for remote wipe" : "برای پاک کردن از راه دور علامت گذاری شده است",
-    "Device settings" : "تنظیمات وسیله",
-    "Allow filesystem access" : "دسترسی به سیستم فایل را مجاز کنید",
+    "Disable all" : "از کار انداختن همه",
+    "Enable all" : "به کار انداختن همه",
+    "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
+    "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
+    "Marked for remote wipe" : "علامت خورده برای زودون دوردست",
+    "Device settings" : "تنظیمات افزاره",
+    "Allow filesystem access" : "اجازهٔ دسترسی به سامانه‌پرونده",
     "Rename" : "تغییرنام",
     "Revoke" : "لغو",
-    "Wipe device" : "وسیله را پاک کنید",
+    "Wipe device" : "زدودن افزاره",
     "Internet Explorer" : "اینترنت اکسپلور",
-    "Edge" : "مرورگر Edge",
+    "Edge" : "اج",
     "Firefox" : "فایرفاکس",
-    "Google Chrome" : "گوگل کروم",
+    "Google Chrome" : "کروم گوگل",
     "Safari" : "سافاری",
-    "Google Chrome for Android" : "گوگل کروم برای اندروید",
-    "iPhone" : "آیفون",
-    "iPad" : "آیپد",
-    "Sync client - {os}" : "همگام سازی مشتری {os}",
-    "This session" : "این جلسه",
-    "Device" : "وسیله",
+    "Google Chrome for Android" : "کروم گوگل برای اندروید",
+    "iPhone" : "آی‌فون",
+    "iPad" : "آی‌پد",
+    "{productName} iOS app" : "کارهٔ iOS {productName}",
+    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
+    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
+    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
+    "Sync client - {os}" : "کارخواه هم‌گام سازی - {os}",
+    "This session" : "این نشست",
+    "Device" : "افزاره",
     "Last activity" : "آخرین فعّالیت",
-    "Devices & sessions" : "وسایل و جلسه ها",
-    "Web, desktop and mobile clients currently logged in to your account." : "مشتریان ، وب ، دسکتاپ و تلفن همراه در حال حاضر به حساب شما وارد شده اند.",
-    "Do you really want to wipe your data from this device?" : "آیا واقعاً می خواهید داده های خود را از این وسیله پاک کنید؟",
-    "Confirm wipe" : "تائید کردن پاکسازی",
+    "Devices & sessions" : "افزاره‌ها و نشست‌ها",
+    "Web, desktop and mobile clients currently logged in to your account." : "کارخواه‌های وب، میزکار و همراهی که اکنون به حسابتان وارد شده‌اند.",
+    "Do you really want to wipe your data from this device?" : "واقعاً می خواهید داده‌هایتان را از این افزاره بزدایید؟",
+    "Confirm wipe" : "تأیید زودن",
     "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
     "Error while updating device token scope" : "هنگام بروزرسانی دامنه توکن وسیله خطایی رخ داد",
     "Error while updating device token name" : "هنگام بروزرسانی نام کد وسیله خطایی رخ داد",
@@ -185,12 +195,24 @@ OC.L10N.register(
     "Password" : "گذرواژه",
     "Done" : "انجام شد",
     "Show QR code for mobile apps" : "نمایش کد QR برای برنامه های تلفن همراه",
-    "Copied!" : "کپی انجام شد!",
-    "Copy" : "کپی",
+    "Copied!" : "رونوشت شد!",
+    "Copy" : "رونوشت",
     "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "برای اجرای این کار شما نیاز به پسوند PHP POSIX دارید. دیدن {linkstart}  مستندات PHP {linkend} برای اطلاعات بیشتر .",
-    "Profile" : "مشخصات",
+    "Last job execution ran {time}. Something seems wrong." : "آخرین کار در {time} اجرا شد. به نظر چیزی اشتباه است.",
+    "Last job ran {relativeTime}." : "آخرین کار در {time} اجرا شد.",
+    "Background job did not run yet!" : "هنوز کار پس‌زمینه‌ای اجار نشده!",
+    "AJAX" : "ای‌جکس",
+    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
+    "Webcron" : "وب‌کرون",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب بار ینمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
+    "Cron (Recommended)" : "کرون (پیشنهادی)",
+    "Use system cron service to call the cron.php file every 5 minutes." : "برای تماس با پرونده cron.php هر 5 دقیقه یکبار از سرویس cron system استفاده کنید.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
+    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
+    "Profile" : "نمایه",
+    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
     "Enable" : "فعال",
+    "Unable to update profile default setting" : "ناتوان در به‌روز رسانی تنظیمات پیش‌گزیدهٔ نمایه",
     "Server-side encryption" : "رمزگذاری سمت سرور",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "\"رمزگذاری سمت سرور\" امکان رمزگذاری پرونده های آپلود شده در این سرور را امکان پذیر می کند. که با محدودیت هایی مانند مجازات عملکرد همراه است ، بنابراین در صورت لزوم فعال کنید.",
     "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
@@ -201,17 +223,19 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
     "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
     "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
-    "Remove group" : "حذف گروه",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "شما در حال حذف گروه {group} هستید. کاربران حذف نخواهند شد.",
-    "Please confirm the group removal " : "لطفاً حذف گروه را تأیید کنید",
+    "Remove group" : "برداشتن گروه",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "در حال برداشتن گروه {group} هستید. کاربران حذف نخواهند شد.",
+    "Please confirm the group removal " : "لطفاً برداشتن گروه را تأیید کنید",
     "Current password" : "گذرواژه کنونی",
     "New password" : "گذرواژه جدید",
     "Change password" : "تغییر گذر واژه",
-    "png or jpg, max. 20 MB" : "png یا jpg, حداکثر. 20 MB",
-    "Picture provided by original account" : "تصویر ارائه شده توسط حساب اصلی",
+    "Your profile picture" : "نگارهٔ نمایه‌تان",
+    "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
+    "Remove profile picture" : "برداشتن نگارهٔ نمایه",
+    "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Cancel" : "منصرف شدن",
-    "Details" : "جزئیات",
-    "You are a member of the following groups:" : "شما عضو گروههای زیر هستید:",
+    "Details" : "جزییات",
+    "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
     "Your email address" : "پست الکترونیکی شما",
     "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
     "Language" : "زبان",
@@ -220,11 +244,24 @@ OC.L10N.register(
     "Locale" : "محل",
     "Your phone number" : "شماره تلفن شما",
     "Add" : "افزودن",
-    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
+    "Default language" : "زبان پیش فرض",
+    "Common languages" : "زبانهای رایج",
+    "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
+    "New user" : "کاربر جدید",
+    "Display name" : "نام جهت نمایش",
+    "Email" : "ایمیل",
+    "Quota" : "سهم",
+    "Avatar" : "آواتار",
+    "Group admin for" : "مدیر گروه برای",
+    "User backend" : "پشتیبان کاربر",
+    "Storage location" : "محل ذخیره سازی",
+    "Last login" : "آخرین ورود",
     "Add new password" : "رمزعبور جدید اضافه کنید",
+    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
     "Add new email address" : "آدرس ایمیل جدید اضافه کنید",
     "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
     "Select user quota" : "سهمیه کاربر را انتخاب کنید",
+    "{size} used" : "{size} مورد استفاده",
     "Delete user" : "حذف کردن کاربر",
     "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
     "Disable user" : "غیرفعال کردن کاربر",
@@ -237,41 +274,20 @@ OC.L10N.register(
     "Account deletion" : "حذف حساب کاربری",
     "Delete {userid}'s account" : "حساب {userid} را حذف کنید",
     "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
-    "Edit User" : "ویرایش کاربر",
-    "{size} used" : "{size} مورد استفاده",
-    "New user" : "کاربر جدید",
-    "Will be autogenerated" : "به صورت خودکار تولید می شود",
-    "Display name" : "نام جهت نمایش",
-    "Email" : "ایمیل",
-    "Default language" : "زبان پیش فرض",
-    "Add a new user" : "افزودن کاربر جدید",
-    "Group admin for" : "مدیر گروه برای",
-    "Quota" : "سهم",
-    "User backend" : "پشتیبان کاربر",
-    "Storage location" : "محل ذخیره سازی",
-    "Last login" : "آخرین ورود",
-    "No users in here" : "هیچ کاربر در اینجا نیست",
+    "Edit" : "ویرایش",
+    "Show user backend" : "نمایش پس زمینه کاربر",
+    "Show storage path" : "نمایش مسیر ذخیره سازی",
+    "Show last login" : "نمایش آخرین ورود",
+    "Send email" : "ارسال ایمیل",
     "Default quota" : "سهمیه پیش فرض",
-    "Common languages" : "زبانهای رایج",
-    "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
+    "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
     "Your apps" : "برنامه های شما",
-    "Active apps" : "برنامه های فعال",
-    "Disabled apps" : "برنامه های غیرفعال شده است",
-    "Updates" : "به روز رسانی ها",
-    "App bundles" : "بسته های برنامه",
     "{license}-licensed" : "دارای مجوز- {license}",
     "Changelog" : "تغییر",
     "Add group" : "افزودن گروه",
     "Active users" : "کاربران فعال",
     "Admins" : "مدیران",
     "Disabled users" : "کاربران غیرفعال شده است",
-    "Default quota:" : "سهمیه پیش فرض:",
-    "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
-    "Show Languages" : "نمایش زبانها",
-    "Show last login" : "نمایش آخرین ورود",
-    "Show user backend" : "نمایش پس زمینه کاربر",
-    "Show storage path" : "نمایش مسیر ذخیره سازی",
-    "Send email to new user" : "ارسال ایمیل به کاربر جدید",
     "Not saved" : "ناموفق در ذخیره",
     "Sending…" : "در حال ارسال",
     "Email sent" : "ایمیل ارسال شد",
@@ -280,45 +296,46 @@ OC.L10N.register(
     "About" : "درباره",
     "Full name" : "نام کامل",
     "Headline" : "عنوان",
+    "Organisation" : "سازمان",
     "Phone number" : "شماره تلفن",
     "Role" : "نقش",
     "Twitter" : "توییتر",
     "Website" : "وب‌ سایت",
+    "Active apps" : "برنامه های فعال",
+    "Disabled apps" : "برنامه های غیرفعال شده است",
+    "Updates" : "به روز رسانی ها",
+    "App bundles" : "بسته های برنامه",
+    "Featured apps" : "برنامه‌های برگزیده",
     "Hide" : "پنهان کردن",
     "Download and enable" : "بارگیری و فعال سازی",
     "Enable untested app" : "برنامه آزمایش نشده را فعال کنید",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
     "Never" : "هرگز",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
-    "Administrator documentation" : "مستندات مدیر",
     "Documentation" : "مستندسازی",
     "Forum" : "انجمن",
     "Login" : "ورود",
-    "Plain" : "ساده",
-    "NT LAN Manager" : "مدیر NT LAN",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "شروع TLS",
+    "SSL" : "SSL",
     "Open documentation" : "بازکردن مستند",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
     "Send mode" : "حالت ارسال",
     "Encryption" : "رمزگذاری",
     "Sendmail mode" : "حالت Sendmail",
     "From address" : "آدرس فرستنده",
-    "Authentication method" : "روش احراز هویت",
-    "Authentication required" : "احراز هویت مورد نیاز است",
     "Server address" : "آدرس سرور",
     "Port" : "درگاه",
+    "Authentication" : "احراز هویت",
+    "Authentication required" : "احراز هویت مورد نیاز است",
     "Credentials" : "اعتبارهای",
     "SMTP Username" : "نام کاربری SMTP",
     "SMTP Password" : "رمز عبور SMTP",
     "Save" : "ذخیره",
-    "Send email" : "ارسال ایمیل",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
     "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
     "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
     "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
     "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را دو برابر کنید و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید",
     "Version" : "نسخه",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
@@ -344,45 +361,23 @@ OC.L10N.register(
     "Check out our blog" : "وبلاگ ما را بررسی کنید",
     "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
     "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
-    "Migration in progress. Please wait until the migration is finished" : "مهاجرت در حال اجراست. لطفا تا اتمام مهاجرت صبر کنید",
-    "Migration started …" : "مهاجرت شروع شد...",
-    "An error occurred while changing your language. Please reload the page and try again." : "در حال تغییر زبان خطایی رخ داد. لطفا صفحه را مجددا بارگذاری کنید و دوباره تلاش کنید.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "هنگام تغییر محلی شما خطایی روی داد. لطفا صفحه را مجددا بارگذاری کنید و دوباره تلاش کنید.",
-    "Select a profile picture" : "انتخاب تصویر پروفایل",
-    "Week starts on {fdow}" : "هفته از چه روزی شروع می شود {fdow}",
-    "Couldn't remove app." : "امکان حذف برنامه وجود ندارد.",
-    "Couldn't update app." : "برنامه را نمی توان به هنگام ساخت.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : " بخش مدیریت از تغییرات رمز عبور پشتیبانی نمی کند ، اما کلید رمزگذاری کاربر به روز شد.",
-    "You need to set your user email before being able to send test emails." : "شما باید قبل از ارسال ایمیل آزمایشی باید تنظیمات ایمیل کاربر را انجام دهید.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : " ابطال این نشانه ممکن است از هدر رفتن وسیله شما جلوگیری کند،اگر هنوز پاک نشده است.",
-    "All languages" : "همه زبانها",
-    "Everyone" : "همه",
-    "An error occured during the request. Unable to proceed." : "هنگام درخواست خطایی روی داد. امکان ادامه وجود ندارد",
-    "Test email settings" : "تنظیمات ایمیل آزمایشی",
-    "Please read carefully before activating server-side encryption: " : "لطفاً قبل از فعال کردن \"رمزگذاری سمت سرور\" با دقت مطالعه کنید:",
-    "Enable encryption" : "فعال کردن رمزگذاری",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "شما باید کلیدهای رمزگذاری خود را از رمزگذاری قدیمی به (ownCloud <= 8.0) نسخه جدید منتقل کنید.لطفاً \"ماژول رمزگذاری پیش فرض\" را فعال کنید و \"مهاجرت به رمزگذاری occ \" را اجرا کنید.",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "شما باید کلیدهای رمزگذاری خود را از رمزگذاری قدیمی به (ownCloud <= 8.0) نسخه جدید منتقل کنید.",
-    "Start migration" : "شروع مهاجرت",
-    "Last job execution ran %s. Something seems wrong." : "آخرین کار انجام شده %s. به نظر می رسد اشتباه است",
-    "Last job ran %s." : "آخرین کار انجام شده %s.",
-    "Background job didn’t run yet!" : "کار پس زمینه هنوز اجرا نشده است!",
-    "Pick background job setting" : "تنظیمات کار پس زمینه را انتخاب کنید",
-    "Recommended" : "پیشنهاد شده",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php باید توسط کاربر سیستم \"%s\" اجرا شود.",
-    "days" : "روز",
-    "Upload new" : "بارگذاری جدید",
-    "Select from Files" : "از میان پرونده ها انتخاب کنید",
-    "Remove image" : "تصویر پاک شود",
-    "Choose as profile picture" : "یک تصویر برای پروفایل انتخاب کنید",
-    "You are using <strong>%s</strong>" : "شما با استفاده از <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "شما با استفاده از <strong>%1$s</strong> از <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
-    "No display name set" : "هیچ نام نمایشی تعیین نشده است",
-    "Address" : "آدرس",
-    "Your postal address" : "آدرس پستی شما",
-    "It can take up to 24 hours before the account is displayed as verified." : "24 ساعت طول می کشد تا اعتبار حساب تأیید شود.",
-    "Link https://…" : "پیوند https://…",
-    "Twitter handle @…" : "دسته توییتر @…",
-    "Avatar" : "آواتار"
+    "You created app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را ایجاد کردید",
+    "An administrator created app password \"{token}\"" : "مدیری گذرواژهٔ کارهٔ «{token}» را ایجاد کرد",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "برای اجرای این کار نیاز به افزونهٔ PHP POSIX دارید. برای جزییات بیش‌تر، {linkstart}مستندات پی‌اچ‌پی{linkend} را ببینید.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "استفاده از خدمت کرون سامانه برای فراخوانی cron.php هر ۵ دقیقه یک بار. مناسب تمامی نمونه‌ها.",
+    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها",
+    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
+    "Edit User" : "ویرایش کاربر",
+    "Will be autogenerated" : "به صورت خودکار تولید می شود",
+    "Add a new user" : "افزودن کاربر جدید",
+    "No users in here" : "هیچ کاربر در اینجا نیست",
+    "Default quota:" : "سهمیه پیش فرض:",
+    "Show Languages" : "نمایش زبانها",
+    "Send email to new user" : "ارسال ایمیل به کاربر جدید",
+    "Plain" : "ساده",
+    "NT LAN Manager" : "مدیر NT LAN",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "شروع TLS",
+    "Authentication method" : "روش احراز هویت"
 },
 "nplurals=2; plural=(n > 1);");
